package org.jboss.security.ssl;

import java.io.IOException;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import javax.net.ssl.KeyManagerFactory;
import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManager;
import javax.net.ssl.TrustManagerFactory;
import org.jboss.logging.Logger;
import org.jboss.security.SecurityDomain;

class Context {

   private static Logger log = Logger.getLogger(Context.class);


   static SSLContext forDomain(SecurityDomain securityDomain) throws IOException {
      SSLContext sslCtx = null;

      try {
         sslCtx = SSLContext.getInstance("TLS");
         KeyManagerFactory e = securityDomain.getKeyManagerFactory();
         if(e == null) {
            throw new IOException("KeyManagerFactory is null for security domain: " + securityDomain.getSecurityDomain());
         } else {
            TrustManagerFactory trustMgr = securityDomain.getTrustManagerFactory();
            TrustManager[] trustMgrs = null;
            if(trustMgr != null) {
               trustMgrs = trustMgr.getTrustManagers();
            }

            sslCtx.init(e.getKeyManagers(), trustMgrs, (SecureRandom)null);
            return sslCtx;
         }
      } catch (NoSuchAlgorithmException var5) {
         log.error("Failed to get SSLContext for TLS algorithm", var5);
         throw new IOException("Failed to get SSLContext for TLS algorithm");
      } catch (KeyManagementException var6) {
         log.error("Failed to init SSLContext", var6);
         throw new IOException("Failed to init SSLContext");
      } catch (SecurityException var7) {
         log.error("Failed to init SSLContext", var7);
         throw new IOException("Failed to init SSLContext");
      }
   }

}
